@@ -10,7 +10,7 @@ use {
     ix: InstructionData,
     exec_at: i64, 
     stop_at: i64,
-    recurr: i64,
+    interval: i64,
     bump: u8,
 )]
 pub struct TaskCreate<'info> {
@@ -64,18 +64,21 @@ pub fn handler(
     ix: InstructionData,
     exec_at: i64, 
     stop_at: i64,
-    recurr: i64,
+    interval: i64,
     bump: u8,
 ) -> ProgramResult {
     // Get accounts.
+    let clock = &ctx.accounts.clock;
     let config = &ctx.accounts.config;
     let daemon = &mut ctx.accounts.daemon;
     let task = &mut ctx.accounts.task;
 
+    clock.unix_timestamp.checked_add(10).unwrap();
+
     // Validate the scheduling chronology.
     require!(exec_at <= stop_at, ErrorCode::InvalidChronology);
-    require!(recurr >= 0, ErrorCode::InvalidRecurrNegative);
-    require!(recurr == 0 || recurr >= config.min_recurr, ErrorCode::InvalidRecurrBelowMin);
+    require!(interval >= 0, ErrorCode::InvalidRecurrNegative);
+    require!(interval == 0 || interval >= config.min_recurr, ErrorCode::InvalidRecurrBelowMin);
 
     // Reject the instruction if it has other signers besides the daemon.
     for acc in ix.accounts.as_slice() {
@@ -87,12 +90,12 @@ pub fn handler(
 
     // Initialize task account.
     task.daemon = daemon.key();
-    task.id = daemon.task_count;
-    task.ix = ix;
-    task.status = TaskStatus::Pending;
     task.exec_at = exec_at;
+    task.int = daemon.task_count;
+    task.interval = interval;
+    task.ix = ix;
+    task.status = TaskStatus::Queued;
     task.stop_at = stop_at;
-    task.recurr = recurr;
     task.bump = bump;
 
     // Increment daemon task counter.
